qermit.zero_noise_extrapolation
===============================

.. currentmodule:: qermit.zero_noise_extrapolation.zne

.. automethod:: qermit.zero_noise_extrapolation.zne.gen_ZNE_MitEx

.. autoclass:: qermit.zero_noise_extrapolation.zne.Folding
    :members:

.. autoclass:: qermit.zero_noise_extrapolation.zne.Fit
    :members:

.. automethod:: qermit.zero_noise_extrapolation.zne.digital_folding_task_gen

.. automethod:: qermit.zero_noise_extrapolation.zne.extrapolation_task_gen

.. automethod:: qermit.zero_noise_extrapolation.zne.gen_initial_compilation_task

.. automethod:: qermit.zero_noise_extrapolation.zne.gen_qubit_relabel_task

.. automethod:: qermit.zero_noise_extrapolation.zne.gen_duplication_task
